@@ -57,13 +57,16 @@ sub DESCRIPTION {
     "Fortran"
 }
 
-#sub DEFAULT_BUILD_DIRECTORY {
+sub DEFAULT_BUILD_DIRECTORY {
 #  TODO:
 # Enable a default builddir only if not specified
-#    my $this = shift;
-#    return $this->SUPER::DEFAULT_BUILD_DIRECTORY() if compat(13);
-#    return '_build';
-#}
+    my $this = shift;
+    # This  is not called if --builddir is set on 'dh ' line.!
+    if (-e "fpm.toml") {
+        return 'build';
+    }
+    return 'debian/build';
+}
 
 #sub IS_GENERATOR_BUILD_SYSTEM {
 #        return 0;
@@ -109,6 +112,7 @@ sub set_fortran_env {
 
 sub configure {
 	my $this=shift;
+        # print "DEBUG; fortran.pm configure before\n";
 	foreach my $command ($this->dhf_commands('configure', @_)) {
 		doit(@$command);
 	}
@@ -123,7 +127,9 @@ sub build {
 
 sub install {
 	my $this=shift;
+        # print "DEBUG fortran.pm install before\n";
 	foreach my $command ($this->dhf_commands('install', @_)) {
+                # print "DEBUG fortran.pm install $command\n";
 		doit(@$command);
 	}
 }
@@ -137,12 +143,12 @@ sub test {
 
 sub clean {
 	my $this=shift;
-
+ 
 	foreach my $command ($this->dhf_commands('clean', @_)) {
+                my $d = join(", ", @$command);
+                # print "DEBUG fortran.pm clean (calling doit) 1 $d\n";
 		doit(@$command);
 	}
-        complex_doit('rm','-rf','debian/tmp-*','debian/build-*');
-	# doit('find', '.', '-name', '*.pyc', '-exec', 'rm', '{}', ';');
 }
 
 sub dhf_commands {
@@ -151,7 +157,23 @@ sub dhf_commands {
 	my @options = @_;
 	my @result;
 
-	doit('dh_fortran',$step);
+        if ($ENV{'FC'}) {
+             my $b = $this->{builddir};
+             $this->_set_builddir("$b\_$ENV{FC}");
+             }
+        my $d = join(", ", @options);
+        my $x = $this->{builddir};
+        my $y = $this->{tmpdir};
+        if ($y) {
+        } else {
+		print "DEBUG: fortran.pm dhf_commands tmpdir not set; setting\n";
+                $this->{tmpdir} = "_tmp\_$ENV{FC}";
+        }
+        $y = $this->{tmpdir};
+       # print "DEBUG fortran.pm dhf_commands builddir $x tmpdir $y \n";
+       # print "DEBUG fortran.pm dhf_commands calling doit dh_fortran $step opts $d\n";
+
+	# doit('dh_fortran',$step);
 	my $dir = $this->get_sourcedir();
 	if (not grep {$_ eq '--dir'} @options and $dir ne '.') {
 		# if --dir is not passed, PYBUILD_DIR can be used
@@ -162,6 +184,9 @@ sub dhf_commands {
 		push @options, '--quiet';
 	}
 
+        # Set builddir on each
+        
+
 	# Pass dh's destdir, if it's not the default value
 	if ($step eq 'install') {
 		my $destdir = shift(@options);
