@@ -1,8 +1,12 @@
 #!/usr/bin/perl -w
 
 use strict;
-use Debian::Debhelper::Dh_Lib;
+# use Debian::Debhelper::Dh_Lib;
 
+# Intercept and monkey-patch dh_auto_coonfigure, etc.
+$ENV{'PATH'}="/usr/share/dh-fortran:$ENV{'PATH'}";
+
+# These may be removed when fully intercepting calls (not noop)
 insert_after("dh_install", "dh_fortran_mod");
 insert_after("dh_install", "dh_fortran_lib");
 
@@ -10,13 +14,6 @@ insert_after("dh_install", "dh_fortran_lib");
 insert_after("dh_fortran_lib", "dh_fortran_cmake");
 insert_after("dh_fortran_lib", "dh_fortran_pkgconf");
 
-my @packages = getpackages();
-my $tmpdir = "debian/tmp";
-if (@packages == 1) {
-    $tmpdir = $packages[0];
-}
-# warning("DEBUG: running with tmpdir $tmpdir");
-
 # dwz will exit 1, breaking on patchelf
 remove_command('dh_dwz');
 1;
